package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Sep 9, 2022
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Hello struct {
ID int `json:"id"`
Greeting string `json:"greeting"`
JSON string `json:"json"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.